#!/usr/bin/python3

import subprocess
import json
from ferreus_orbit.systemtool import SystemTool


class LShw(SystemTool):
    """
    Class for retrieve informations by lshw command
    """
    select = 0

    def run(self) -> list:
        """
        Get informations by lshw command

        Returns:
            list: list of device
        """
        self.logger.info("Retrieve lsw infos")
        cmd = "lshw -c disk -json".split()
        result = subprocess.run(cmd, capture_output=True, check=True, text=True, timeout=30)
        hws = json.loads(result.stdout)
        disks = []
        for hw in hws:
            disk = dict((k, hw[k]) for k in ['vendor', 'product', 'serial', 'size', 'version'] if k in hw)
            names = hw['logicalname'] if isinstance(hw['logicalname'], list) else [hw['logicalname']]
            for name in names:
                if name.startswith('/dev'):
                    disk['device'] = name
                elif name.startswith('/srv/node'):
                    disk['mountpoint'] = name
            disks.append(disk)
        return disks

    def get(self, select: bool = False, **kwargs) -> dict:
        """
        Return one item from entries matching arbitrary keyword arguments

        Parameters:
            select (bool): if selection mode

        Returns:
            dict: dict of device
        """
        lookup = []
        result = {}
        for item in self.entries:
            if any(item.get(key) == value for key, value in kwargs.items()):
                lookup.append(item)
        if not lookup:
            self.logger.info(f"{self.__class__.__name__} found no entry matching '{kwargs}'")
        elif len(lookup) > 1:
            self.logger.warning(f"{self.__class__.__name__} found more than 1 disk found for '{kwargs}', result: {lookup}")
        else:
            result = lookup[0]
        return result
